==> BoutrosLab.plotting.general_5.9.2.tar.gz: BoutrosLab.plotting.general/R/write.metadata.R <==
# The BoutrosLab.plotting.general package is copyright (c) 2013 Ontario Institute for Cancer Research (OICR)
# This package and its accompanying libraries is free software; you can redistribute it and/or modify it under the terms of the GPL
# (either version 1, or at your option, any later version) or the Artistic License 2.0.  Refer to LICENSE for the full license text.
# OICR makes no representations whatsoever as to the SOFTWARE contained herein.  It is experimental in nature and is provided WITHOUT
# WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE OR ANY OTHER WARRANTY, EXPRESS OR IMPLIED. OICR MAKES NO REPRESENTATION
# OR WARRANTY THAT THE USE OF THIS SOFTWARE WILL NOT INFRINGE ANY PATENT OR OTHER PROPRIETARY RIGHT.
# By downloading this SOFTWARE, your Institution hereby indemnifies OICR against any loss, claim, damage or liability, of whatsoever kind or
# nature, which may arise from your Institution's respective use, handling or storage of the SOFTWARE.
# If publications result from research using this SOFTWARE, we ask that the Ontario Institute for Cancer Research be acknowledged and/or
# credit be given to OICR scientists, as scientifically appropriate.

### FUNCTION TO WRITE METADATA ####################################################################
write.metadata <- function(filename = NULL, description = NULL, verbose = FALSE) {

	exiftool.location <- Sys.which('exiftool');

	# whether to output stuff or not
	if (FALSE == verbose) {
		standard.out <- NULL;
		}
	else {
		standard.out <- '';
		}

	# write metadata only if file exists and exiftool has been installed
	if (!is.null(filename) && exiftool.location != '') {

		# retrieve software versions
		R.version <- getRversion();
		plotting.survival.version <- '';

		lattice.version			<- packageVersion('lattice');
		lattice.extra.version		<- packageVersion('latticeExtra');
		plotting.general.version 	<- packageVersion('BoutrosLab.plotting.general');
		tryCatch(
			plotting.survival.version <- packageVersion('BoutrosLab.plotting.survival'),

			error = function(e) {
				plotting.survival.version <- 'unknown';
				}
			);

		# retrieve computer information
		operating.system <- paste(Sys.info()[['sysname']], Sys.info()[['version']], collapse = ' ');
		machine <- Sys.info()[['machine']];

		# retrieve username
		author <- Sys.info()[['user']];

		# write author of plot
		system2(
			'exiftool',
			args = paste0(
				" -Author='",
				author,
				"' -overwrite_original ",
				filename
				),
			stdout = standard.out
			);

		# write R version used to make plot
		system2(
			'exiftool',
			args = paste0(
				" -Software='R ",
				R.version,
				' | lattice ',
				lattice.version,
				' | latticeExtra ',
				lattice.extra.version,
				' | BL.plotting.general ',
				plotting.general.version,
				' | BL.plotting.survival ',
				plotting.survival.version,
				"' -overwrite_original ",
				filename
				),
			stdout = standard.out
			);

		# description of figure
		system2(
			'exiftool',
			args = paste0(
				"-ImageDescription='",
				description,
				"' -overwrite_original ",
				filename
				),
			stdout = standard.out
			);

		# operating system
		system2(
			'exiftool',
			args = paste0(
				" -SoftwareVersion='",
				operating.system,
				"' -overwrite_original ",
				filename
				),
			stdout = standard.out
			);

		# hardware
		system2(
			'exiftool',
			args = paste0(
				" -Make='",
				machine,
				"' -overwrite_original ",
				filename
				),
			stdout = standard.out
			);
		}
	}

==> BoutrosLab.plotting.general_7.1.2.tar.gz: BoutrosLab.plotting.general/R/write.metadata.R <==
# The BoutrosLab.plotting.general package is copyright (c) 2013 Ontario Institute for Cancer Research (OICR)
# This package and its accompanying libraries is free software; you can redistribute it and/or modify it under the terms of the GPL
# (either version 1, or at your option, any later version) or the Artistic License 2.0.  Refer to LICENSE for the full license text.
# OICR makes no representations whatsoever as to the SOFTWARE contained herein.  It is experimental in nature and is provided WITHOUT
# WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE OR ANY OTHER WARRANTY, EXPRESS OR IMPLIED. OICR MAKES NO REPRESENTATION
# OR WARRANTY THAT THE USE OF THIS SOFTWARE WILL NOT INFRINGE ANY PATENT OR OTHER PROPRIETARY RIGHT.
# By downloading this SOFTWARE, your Institution hereby indemnifies OICR against any loss, claim, damage or liability, of whatsoever kind or
# nature, which may arise from your Institution's respective use, handling or storage of the SOFTWARE.
# If publications result from research using this SOFTWARE, we ask that the Ontario Institute for Cancer Research be acknowledged and/or
# credit be given to OICR scientists, as scientifically appropriate.

### FUNCTION TO WRITE METADATA ####################################################################
write.metadata <- function(filename = NULL, description = NULL, verbose = FALSE) {

	exiftool.location <- Sys.which('exiftool');

	# whether to output stuff or not
	if (FALSE == verbose) {
		standard.out <- NULL;
		}
	else {
		standard.out <- '';
		}

	# write metadata only if file exists and exiftool has been installed
	if (!is.null(filename) && exiftool.location != '') {

		# retrieve software versions
		R.version <- getRversion();

		lattice.version			<- packageVersion('lattice');
		lattice.extra.version		<- packageVersion('latticeExtra');
		plotting.general.version 	<- packageVersion('BoutrosLab.plotting.general');
		plotting.survival.version <- tryCatch({
			packageVersion('BoutrosLab.plotting.survival');
			}, error = function(e) {
			'unknown';
			});

		software.versions = paste0(
			'R ',
			R.version,
			' | lattice ',
			lattice.version,
			' | latticeExtra ',
			lattice.extra.version,
			' | BL.plotting.general ',
			plotting.general.version,
			' | BL.plotting.survival ',
			plotting.survival.version
			);

		# retrieve computer information
		operating.system <- paste(Sys.info()[['sysname']], Sys.info()[['version']], collapse = ' ');
		machine <- Sys.info()[['machine']];

		# retrieve username
		author <- Sys.info()[['user']];

		# write author, software, description of figure,
		# os info & hardware info
		system2(
			'exiftool',
			args = paste0(
				'-Author="',
				author,
				'" -Software="',
				software.versions,
				'" -ImageDescription="',
				description,
				'" -HostComputer="',
				operating.system,
				'" -Make="',
				machine,
				'" -overwrite_original ',
				filename
				),
			stdout = standard.out
			);
		}
	}
